@@ -1,7 +1,7 @@
 /**
  ** Simple entropy harvester based upon the havege RNG
  **
- ** Copyright 2018-2021 Jirka Hladky hladky DOT jiri AT gmail DOT com
+ ** Copyright 2018-2022 Jirka Hladky hladky DOT jiri AT gmail DOT com
  ** Copyright 2009-2014 Gary Wuertz gary@issiweb.com
  ** Copyright 2011-2012 BenEleventh Consulting manolson@beneleventh.com
  **
@@ -31,7 +31,7 @@ extern "C" {
  * header/package version as a numeric major, minor, patch triple. See havege_version()
  * below for usage.
  */
-#define  HAVEGE_PREP_VERSION  "1.9.15"
+#define  HAVEGE_PREP_VERSION  "1.9.19"
 /**
  * Basic types
  */
@@ -56,7 +56,7 @@ typedef void (*pMsg)(const char *format, ...);
 typedef int (*pRawIn)(volatile H_UINT *pData, H_UINT szData);
 /**
  * options for H_PARAMS below. Lower byte transferred from verbose settings
- * upper byte set by diagnositic run options 
+ * upper byte set by diagnositic run options
  */
 #define H_VERBOSE         0x001           /* deprecated from ver 1.7       */
 #define H_DEBUG_INFO      0x001           /* Show config info, retries     */
@@ -65,14 +65,16 @@ typedef int (*pRawIn)(volatile H_UINT *pData, H_UINT szData);
 #define H_DEBUG_LOOP      0x008           /* Show loop parameters          */
 #define H_DEBUG_COMPILE   0x010           /* Show assembly info            */
 #define H_DEBUG_OLT       0x020           /* Show all test info            */
+#define H_RNDADDENTROPY_INFO 0x040        /* RNDADDENTROPY info            */
 
 #define H_DEBUG_RAW_OUT   0x100           /* diagnostic output             */
 #define H_DEBUG_RAW_IN    0x200           /* diagnostic input              */
 #define H_DEBUG_TEST_IN   0x400           /* input test data               */
+
 /**
  * Initialization parameters. Use non-zero values to override default values.
  * Notes:
- * 
+ *
  * 1) Correspondence between provided value and value of H_PTR members are:
  *    ioSz <==> i_readSz, collectSize <==> i_collectSz, nCores <==> n_cores,
  *    options <==> havege_opts
@@ -159,6 +161,7 @@ typedef struct h_anchor {
    H_UINT      m_sz;                      /* size of thread ipc area (bytes)  */
    H_UINT      n_cores;                   /* number of cores                  */
    H_UINT      n_fills;                   /* number of buffer fills           */
+   size_t      n_entropy_bytes;           /* total amount of entropy (byte)   */
 } *H_PTR;
 /**
  * Fail/Success counters for tot and production tests.
